Coverage for test_emr.py: 64%

# Coverage for test_emr.py : 64%

## 11 statements 7 run 4 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 | # -*- coding: utf-8 -*- import boto3 import pytest from jungle import cli @pytest.mark.parametrize('cluster_name', [ ('aa'), ]) def test_emr_ls(runner, emr, cluster_name): """test for emr ls""" result = runner.invoke(cli.cli, ['emr', 'ls', cluster_name]) assert result.exit_code == 0 def test_mock_emr(emr): client = boto3.client('emr') results = client.list_clusters( ClusterStates=['RUNNING', 'STARTING', 'BOOTSTRAPPING', 'WAITING'] ) print(results) assert False